Package: Seurat
Version: 5.5.0
Title: Tools for Single Cell Genomics
Description: A toolkit for quality control, analysis, and exploration of single cell RNA sequencing data. 'Seurat' aims to enable users to identify and interpret sources of heterogeneity from single cell transcriptomic measurements, and to integrate diverse types of single cell data. See Satija R, Farrell J, Gennert D, et al (2015) <doi:10.1038/nbt.3192>, Macosko E, Basu A, Satija R, et al (2015) <doi:10.1016/j.cell.2015.05.002>, Stuart T, Butler A, et al (2019) <doi:10.1016/j.cell.2019.05.031>, and Hao, Hao, et al (2020) <doi:10.1101/2020.10.12.335331> for more details.
Authors@R: c(
  person(given = "Andrew", family = "Butler", email = "abutler@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0003-3608-0463")),
  person(given = "Saket", family = "Choudhary", email = "schoudhary@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0001-5202-7633")),
  person(given = 'David', family = 'Collins', email = 'dcollins@nygenome.org', role = 'ctb', comment = c(ORCID = '0000-0001-9243-7821')),
  person(given = "Charlotte", family = "Darby", email = "cdarby@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0003-2195-5300")),
  person(given = "Jeff", family = "Farrell", email = "jfarrell@g.harvard.edu", role = "ctb"),
  person(given = "Isabella", family = "Grabski", email = "igrabski@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0002-0616-5469")),
  person(given = "Christoph", family = "Hafemeister", email = "chafemeister@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0001-6365-8254")),
  person(given = "Yuhan", family = "Hao", email = "yhao@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0002-1810-0822")),
  person(given = "Austin", family = "Hartman", email = "ahartman@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0001-7278-1852")),
  person(given = "Paul", family = "Hoffman", email = "hoff0792@umn.edu", role = "ctb", comment = c(ORCID = "0000-0002-7693-8957")),
  person(given = "Jaison", family = "Jain", email = "jjain@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0002-9478-5018")),
  person(given = "Longda", family = "Jiang", email = "ljiang@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0003-4964-6497")),
  person(given = "Madeline", family = "Kowalski", email = "mkowalski@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0002-5655-7620")),
  person(given = "Skylar", family = "Li", email = "sli@nygenome.org", role = "ctb"),
  person(given = "Gesmira", family = "Molla", email = 'gmolla@nygenome.org', role = 'ctb', comment = c(ORCID = '0000-0002-8628-5056')),
  person(given = "Efthymia", family = "Papalexi", email = "epapalexi@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0001-5898-694X")),
  person(given = "Patrick", family = "Roelli", email = "proelli@nygenome.org", role = "ctb"),
  person(given = "Rahul", family = "Satija", email = "seurat@nygenome.org", role = c("aut", "cre"), comment = c(ORCID = "0000-0001-9448-8833")),
  person(given = "Karthik", family = "Shekhar", email = "kshekhar@berkeley.edu", role = "ctb"),
  person(given = "Anagha", family = "Shenoy", email = "ashenoy@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0002-0537-6862")),
  person(given = "Avi", family = "Srivastava", email = "asrivastava@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0001-9798-2079")),
  person(given = "Tim", family = "Stuart", email = "tstuart@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0002-3044-0897")),
  person(given = "Kristof", family = "Torkenczy", email = "", role = "ctb", comment = c(ORCID = "0000-0002-4869-7957")),
  person(given = "Brian", family = "Zhang", email = "brianzhang@nygenome.org", role = "ctb"),
  person(given = "Shiwei", family = "Zheng", email = "szheng@nygenome.org", role = "ctb", comment = c(ORCID = "0000-0001-6682-6743")),
  person("Satija Lab and Collaborators", role = "fnd")
  )
License: MIT + file LICENSE
URL: https://satijalab.org/seurat, https://github.com/satijalab/seurat
BugReports: https://github.com/satijalab/seurat/issues
Additional_repositories: https://satijalab.r-universe.dev,
        https://bnprks.r-universe.dev
Depends: R (>= 4.0.0), methods, SeuratObject (>= 5.0.2)
Imports: cluster, cowplot, fastDummies, fitdistrplus, future,
        future.apply, generics (>= 0.1.3), ggplot2 (>= 3.3.0), ggrepel,
        ggridges, graphics, grDevices, grid, httr, ica, igraph, irlba,
        jsonlite, KernSmooth, lifecycle, lmtest, MASS, Matrix (>=
        1.5-0), matrixStats, miniUI, patchwork, pbapply, plotly (>=
        4.9.0), png, progressr, RANN, RColorBrewer, Rcpp (>= 1.0.7),
        RcppAnnoy (>= 0.0.18), RcppHNSW, reticulate, rlang, ROCR,
        RSpectra, Rtsne, scales, scattermore (>= 1.2), sctransform (>=
        0.4.1), shiny, spatstat.explore, spatstat.geom, stats, tibble,
        tools, utils, uwot (>= 0.1.10)
Suggests: ape, arrow, base64enc, Biobase, BiocGenerics, BPCells,
        data.table, DESeq2, DelayedArray, enrichR, GenomicRanges,
        GenomeInfoDb, glmGamPoi, ggrastr, harmony, hdf5r, IRanges,
        leidenbase, limma, magrittr, MAST, metap, mixtools, monocle,
        presto, rsvd, R.utils, Rfast2, rtracklayer, S4Vectors, sf (>=
        1.0.0), sp, SingleCellExperiment, SummarizedExperiment,
        testthat, VGAM
LinkingTo: Rcpp (>= 0.11.0), RcppEigen, RcppProgress
BuildManual: true
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Collate: 'RcppExports.R' 'reexports.R' 'generics.R' 'clustering.R'
        'visualization.R' 'convenience.R' 'data.R'
        'differential_expression.R' 'dimensional_reduction.R'
        'integration.R' 'zzz.R' 'integration5.R' 'mixscape.R'
        'objects.R' 'preprocessing.R' 'preprocessing5.R' 'roxygen.R'
        'sketching.R' 'tree.R' 'utilities.R'
NeedsCompilation: yes
Packaged: 2026-04-21 22:46:06 UTC; root
Author: Andrew Butler [ctb] (ORCID: <https://orcid.org/0000-0003-3608-0463>),
  Saket Choudhary [ctb] (ORCID: <https://orcid.org/0000-0001-5202-7633>),
  David Collins [ctb] (ORCID: <https://orcid.org/0000-0001-9243-7821>),
  Charlotte Darby [ctb] (ORCID: <https://orcid.org/0000-0003-2195-5300>),
  Jeff Farrell [ctb],
  Isabella Grabski [ctb] (ORCID: <https://orcid.org/0000-0002-0616-5469>),
  Christoph Hafemeister [ctb] (ORCID:
    <https://orcid.org/0000-0001-6365-8254>),
  Yuhan Hao [ctb] (ORCID: <https://orcid.org/0000-0002-1810-0822>),
  Austin Hartman [ctb] (ORCID: <https://orcid.org/0000-0001-7278-1852>),
  Paul Hoffman [ctb] (ORCID: <https://orcid.org/0000-0002-7693-8957>),
  Jaison Jain [ctb] (ORCID: <https://orcid.org/0000-0002-9478-5018>),
  Longda Jiang [ctb] (ORCID: <https://orcid.org/0000-0003-4964-6497>),
  Madeline Kowalski [ctb] (ORCID:
    <https://orcid.org/0000-0002-5655-7620>),
  Skylar Li [ctb],
  Gesmira Molla [ctb] (ORCID: <https://orcid.org/0000-0002-8628-5056>),
  Efthymia Papalexi [ctb] (ORCID:
    <https://orcid.org/0000-0001-5898-694X>),
  Patrick Roelli [ctb],
  Rahul Satija [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-9448-8833>),
  Karthik Shekhar [ctb],
  Anagha Shenoy [ctb] (ORCID: <https://orcid.org/0000-0002-0537-6862>),
  Avi Srivastava [ctb] (ORCID: <https://orcid.org/0000-0001-9798-2079>),
  Tim Stuart [ctb] (ORCID: <https://orcid.org/0000-0002-3044-0897>),
  Kristof Torkenczy [ctb] (ORCID:
    <https://orcid.org/0000-0002-4869-7957>),
  Brian Zhang [ctb],
  Shiwei Zheng [ctb] (ORCID: <https://orcid.org/0000-0001-6682-6743>),
  Satija Lab and Collaborators [fnd]
Maintainer: Rahul Satija <seurat@nygenome.org>
Repository: CRAN
Date/Publication: 2026-04-22 08:10:02 UTC
