# Generated by roxygen2: do not edit by hand

S3method("SCTResults<-",SCTAssay)
S3method("SCTResults<-",SCTModel)
S3method("[",SlideSeq)
S3method("[",VisiumV1)
S3method("levels<-",SCTAssay)
S3method(.CalcN,IterableMatrix)
S3method(AddModuleScore,Assay)
S3method(AddModuleScore,Seurat)
S3method(AddModuleScore,StdAssay)
S3method(AnnotateAnchors,IntegrationAnchorSet)
S3method(AnnotateAnchors,TransferAnchorSet)
S3method(AnnotateAnchors,default)
S3method(Cells,SCTAssay)
S3method(Cells,SCTModel)
S3method(Cells,STARmap)
S3method(Cells,SlideSeq)
S3method(Cells,VisiumV1)
S3method(Features,SCTAssay)
S3method(Features,SCTModel)
S3method(FetchData,VisiumV1)
S3method(FetchResiduals,SCTAssay)
S3method(FetchResiduals,Seurat)
S3method(FindClusters,Seurat)
S3method(FindClusters,default)
S3method(FindMarkers,Assay)
S3method(FindMarkers,DimReduc)
S3method(FindMarkers,SCTAssay)
S3method(FindMarkers,Seurat)
S3method(FindMarkers,StdAssay)
S3method(FindMarkers,default)
S3method(FindNeighbors,Assay)
S3method(FindNeighbors,Seurat)
S3method(FindNeighbors,default)
S3method(FindNeighbors,dist)
S3method(FindSpatiallyVariableFeatures,Assay)
S3method(FindSpatiallyVariableFeatures,Seurat)
S3method(FindSpatiallyVariableFeatures,StdAssay)
S3method(FindSpatiallyVariableFeatures,default)
S3method(FindVariableFeatures,Assay)
S3method(FindVariableFeatures,SCTAssay)
S3method(FindVariableFeatures,Seurat)
S3method(FindVariableFeatures,StdAssay)
S3method(FindVariableFeatures,V3Matrix)
S3method(FindVariableFeatures,default)
S3method(FoldChange,Assay)
S3method(FoldChange,DimReduc)
S3method(FoldChange,SCTAssay)
S3method(FoldChange,Seurat)
S3method(FoldChange,StdAssay)
S3method(FoldChange,default)
S3method(GetAssay,Seurat)
S3method(GetImage,STARmap)
S3method(GetImage,SlideSeq)
S3method(GetImage,VisiumV1)
S3method(GetImage,VisiumV2)
S3method(GetTissueCoordinates,STARmap)
S3method(GetTissueCoordinates,SlideSeq)
S3method(GetTissueCoordinates,VisiumV1)
S3method(GetTissueCoordinates,VisiumV2)
S3method(HVFInfo,SCTAssay)
S3method(IntegrateEmbeddings,IntegrationAnchorSet)
S3method(IntegrateEmbeddings,TransferAnchorSet)
S3method(LeverageScore,Assay)
S3method(LeverageScore,Seurat)
S3method(LeverageScore,StdAssay)
S3method(LeverageScore,default)
S3method(LogNormalize,IterableMatrix)
S3method(LogNormalize,V3Matrix)
S3method(LogNormalize,data.frame)
S3method(LogNormalize,default)
S3method(MappingScore,AnchorSet)
S3method(MappingScore,default)
S3method(NormalizeData,Assay)
S3method(NormalizeData,Seurat)
S3method(NormalizeData,StdAssay)
S3method(NormalizeData,V3Matrix)
S3method(NormalizeData,default)
S3method(ProjectCellEmbeddings,Assay)
S3method(ProjectCellEmbeddings,IterableMatrix)
S3method(ProjectCellEmbeddings,SCTAssay)
S3method(ProjectCellEmbeddings,Seurat)
S3method(ProjectCellEmbeddings,StdAssay)
S3method(ProjectCellEmbeddings,default)
S3method(ProjectUMAP,DimReduc)
S3method(ProjectUMAP,Seurat)
S3method(ProjectUMAP,default)
S3method(PseudobulkExpression,Assay)
S3method(PseudobulkExpression,Seurat)
S3method(PseudobulkExpression,StdAssay)
S3method(Radius,STARmap)
S3method(Radius,SlideSeq)
S3method(Radius,VisiumV1)
S3method(RenameCells,SCTAssay)
S3method(RenameCells,STARmap)
S3method(RenameCells,SlideSeq)
S3method(RenameCells,VisiumV1)
S3method(RunCCA,Seurat)
S3method(RunCCA,default)
S3method(RunGraphLaplacian,Seurat)
S3method(RunGraphLaplacian,default)
S3method(RunICA,Assay)
S3method(RunICA,Seurat)
S3method(RunICA,StdAssay)
S3method(RunICA,default)
S3method(RunLDA,Assay)
S3method(RunLDA,Seurat)
S3method(RunLDA,default)
S3method(RunPCA,Assay)
S3method(RunPCA,Seurat)
S3method(RunPCA,Seurat5)
S3method(RunPCA,StdAssay)
S3method(RunPCA,default)
S3method(RunSLSI,Assay)
S3method(RunSLSI,Seurat)
S3method(RunSLSI,StdAssay)
S3method(RunSLSI,default)
S3method(RunSPCA,Assay)
S3method(RunSPCA,Assay5)
S3method(RunSPCA,Seurat)
S3method(RunSPCA,default)
S3method(RunTSNE,DimReduc)
S3method(RunTSNE,Seurat)
S3method(RunTSNE,dist)
S3method(RunTSNE,matrix)
S3method(RunUMAP,Graph)
S3method(RunUMAP,Neighbor)
S3method(RunUMAP,Seurat)
S3method(RunUMAP,default)
S3method(SCTResults,SCTAssay)
S3method(SCTResults,SCTModel)
S3method(SCTResults,Seurat)
S3method(SCTransform,Assay)
S3method(SCTransform,IterableMatrix)
S3method(SCTransform,Seurat)
S3method(SCTransform,StdAssay)
S3method(SCTransform,default)
S3method(ScaleData,Assay)
S3method(ScaleData,IterableMatrix)
S3method(ScaleData,Seurat)
S3method(ScaleData,StdAssay)
S3method(ScaleData,default)
S3method(ScaleFactors,STARmap)
S3method(ScaleFactors,SlideSeq)
S3method(ScaleFactors,VisiumV1)
S3method(ScaleFactors,VisiumV2)
S3method(ScoreJackStraw,DimReduc)
S3method(ScoreJackStraw,JackStrawData)
S3method(ScoreJackStraw,Seurat)
S3method(VST,IterableMatrix)
S3method(VST,default)
S3method(VST,dgCMatrix)
S3method(VST,matrix)
S3method(VariableFeatures,SCTAssay)
S3method(VariableFeatures,SCTModel)
S3method(as.CellDataSet,Seurat)
S3method(as.Seurat,CellDataSet)
S3method(as.Seurat,SingleCellExperiment)
S3method(as.SingleCellExperiment,Seurat)
S3method(as.data.frame,Matrix)
S3method(as.sparse,H5Group)
S3method(as.sparse,IterableMatrix)
S3method(components,SCTAssay)
S3method(dim,STARmap)
S3method(dim,SlideSeq)
S3method(dim,VisiumV1)
S3method(dim,VisiumV2)
S3method(fortify,Centroids)
S3method(fortify,Molecules)
S3method(fortify,Segmentation)
S3method(levels,SCTAssay)
S3method(merge,SCTAssay)
S3method(subset,AnchorSet)
S3method(subset,SCTAssay)
S3method(subset,STARmap)
S3method(subset,SlideSeq)
S3method(subset,VisiumV1)
export("%iff%")
export("%||%")
export("DefaultAssay<-")
export("Idents<-")
export("Index<-")
export("JS<-")
export("Key<-")
export("Loadings<-")
export("Misc<-")
export("Project<-")
export("SCTResults<-")
export("Tool<-")
export("VariableFeatures<-")
export(AddAzimuthResults)
export(AddMetaData)
export(AddModuleScore)
export(AggregateExpression)
export(AnnotateAnchors)
export(Assays)
export(AugmentPlot)
export(AutoPointSize)
export(AverageExpression)
export(BGTextColor)
export(BarcodeInflectionsPlot)
export(BlackAndWhite)
export(BlueAndRed)
export(BoldTitle)
export(BridgeCellsRepresentation)
export(BuildClusterTree)
export(BuildNicheAssay)
export(CCAIntegration)
export(CalcPerturbSig)
export(CalculateBarcodeInflections)
export(CaseMatch)
export(CellCycleScoring)
export(CellScatter)
export(CellSelector)
export(Cells)
export(CellsByIdentities)
export(CenterTitle)
export(CollapseEmbeddingOutliers)
export(CollapseSpeciesExpressionMatrix)
export(ColorDimSplit)
export(CombinePlots)
export(Command)
export(CountSketch)
export(CreateAssayObject)
export(CreateCategoryMatrix)
export(CreateDimReducObject)
export(CreateSCTAssayObject)
export(CreateSeuratObject)
export(CustomDistance)
export(CustomPalette)
export(DEenrichRPlot)
export(DarkTheme)
export(DefaultAssay)
export(DietSeurat)
export(DimHeatmap)
export(DimPlot)
export(DiscretePalette)
export(Distances)
export(DoHeatmap)
export(DotPlot)
export(ElbowPlot)
export(Embeddings)
export(ExpMean)
export(ExpSD)
export(ExpVar)
export(FastRPCAIntegration)
export(FastRowScale)
export(FeatureLocator)
export(FeaturePlot)
export(FeatureScatter)
export(FetchData)
export(FetchResiduals)
export(FilterSlideSeq)
export(FindAllMarkers)
export(FindBridgeIntegrationAnchors)
export(FindBridgeTransferAnchors)
export(FindClusters)
export(FindConservedMarkers)
export(FindIntegrationAnchors)
export(FindMarkers)
export(FindMultiModalNeighbors)
export(FindNeighbors)
export(FindSpatiallyVariableFeatures)
export(FindSubCluster)
export(FindTransferAnchors)
export(FindVariableFeatures)
export(FoldChange)
export(FontSize)
export(GaussianSketch)
export(GeneSymbolThesarus)
export(GetAssay)
export(GetAssayData)
export(GetImage)
export(GetIntegrationData)
export(GetResidual)
export(GetTissueCoordinates)
export(GetTransferPredictions)
export(GroupCorrelation)
export(GroupCorrelationPlot)
export(HTODemux)
export(HTOHeatmap)
export(HVFInfo)
export(HarmonyIntegration)
export(HoverLocator)
export(IFeaturePlot)
export(ISpatialDimPlot)
export(ISpatialFeaturePlot)
export(Idents)
export(ImageDimPlot)
export(ImageFeaturePlot)
export(Images)
export(Index)
export(Indices)
export(IntegrateData)
export(IntegrateEmbeddings)
export(IntegrateLayers)
export(Intensity)
export(InteractiveSpatialPlot)
export(IsGlobal)
export(JS)
export(JackStraw)
export(JackStrawPlot)
export(JointPCAIntegration)
export(Key)
export(L2CCA)
export(L2Dim)
export(LabelClusters)
export(LabelPoints)
export(LeverageScore)
export(LinkedDimPlot)
export(LinkedFeaturePlot)
export(Load10X_Spatial)
export(LoadAkoya)
export(LoadAnnoyIndex)
export(LoadCurioSeeker)
export(LoadHuBMAPCODEX)
export(LoadNanostring)
export(LoadSTARmap)
export(LoadVizgen)
export(LoadXenium)
export(Loadings)
export(LocalStruct)
export(LogNormalize)
export(LogSeuratCommand)
export(LogVMR)
export(Luminance)
export(MULTIseqDemux)
export(MapQuery)
export(MappingScore)
export(MetaFeature)
export(MinMax)
export(Misc)
export(MixingMetric)
export(MixscapeHeatmap)
export(MixscapeLDA)
export(NNPlot)
export(NNtoGraph)
export(Neighbors)
export(NoAxes)
export(NoGrid)
export(NoLegend)
export(NormalizeData)
export(PCAPlot)
export(PCASigGenes)
export(PCHeatmap)
export(PercentAbove)
export(PercentageFeatureSet)
export(PlotClusterTree)
export(PlotPerturbScore)
export(PolyDimPlot)
export(PolyFeaturePlot)
export(PredictAssay)
export(PrepLDA)
export(PrepSCTFindMarkers)
export(PrepSCTIntegration)
export(PrepareBridgeReference)
export(Project)
export(ProjectCellEmbeddings)
export(ProjectData)
export(ProjectDim)
export(ProjectDimReduc)
export(ProjectIntegration)
export(ProjectUMAP)
export(PseudobulkExpression)
export(PurpleAndYellow)
export(RPCAIntegration)
export(Radius)
export(Read10X)
export(Read10X_Coordinates)
export(Read10X_HD_GeoJson)
export(Read10X_Image)
export(Read10X_ScaleFactors)
export(Read10X_Segmentations)
export(Read10X_h5)
export(Read10X_probe_metadata)
export(ReadAkoya)
export(ReadMtx)
export(ReadNanostring)
export(ReadParseBio)
export(ReadSTARsolo)
export(ReadSlideSeq)
export(ReadVitessce)
export(ReadVizgen)
export(ReadXenium)
export(Reductions)
export(RegroupIdents)
export(RelativeCounts)
export(RenameCells)
export(RenameIdents)
export(ReorderIdent)
export(RestoreLegend)
export(RidgePlot)
export(RotatedAxis)
export(RowMergeSparseMatrices)
export(RunCCA)
export(RunGraphLaplacian)
export(RunICA)
export(RunLDA)
export(RunLeiden)
export(RunMarkVario)
export(RunMixscape)
export(RunMoransI)
export(RunPCA)
export(RunSLSI)
export(RunSPCA)
export(RunTSNE)
export(RunUMAP)
export(SCTResults)
export(SCTransform)
export(SVFInfo)
export(SampleUMI)
export(SaveAnnoyIndex)
export(ScaleData)
export(ScaleFactors)
export(ScoreJackStraw)
export(SelectIntegrationFeatures)
export(SelectIntegrationFeatures5)
export(SelectSCTIntegrationFeatures)
export(SetAssayData)
export(SetIdent)
export(SetIntegrationData)
export(SetQuantile)
export(SeuratAxes)
export(SeuratTheme)
export(SingleCorPlot)
export(SingleDimPlot)
export(SingleExIPlot)
export(SingleImageMap)
export(SingleImagePlot)
export(SingleRasterMap)
export(SingleSpatialPlot)
export(SketchData)
export(SpatialDimPlot)
export(SpatialFeaturePlot)
export(SpatialPlot)
export(SpatialTheme)
export(SpatiallyVariableFeatures)
export(SplitObject)
export(StashIdent)
export(Stdev)
export(SubsetByBarcodeInflections)
export(TSNEPlot)
export(Tool)
export(TopCells)
export(TopFeatures)
export(TopNeighbors)
export(TransferData)
export(TransferSketchLabels)
export(UMAPPlot)
export(UnSketchEmbeddings)
export(UpdateSCTAssays)
export(UpdateSeuratObject)
export(UpdateSymbolList)
export(VST)
export(VariableFeaturePlot)
export(VariableFeatures)
export(VizDimLoadings)
export(VlnPlot)
export(WhichCells)
export(WhiteBackground)
export(as.CellDataSet)
export(as.Graph)
export(as.Neighbor)
export(as.Seurat)
export(as.SingleCellExperiment)
export(as.sparse)
export(components)
export(scalefactors)
exportClasses(AnchorSet)
exportClasses(Assay)
exportClasses(BridgeReferenceSet)
exportClasses(DimReduc)
exportClasses(Graph)
exportClasses(IntegrationAnchorSet)
exportClasses(IntegrationData)
exportClasses(JackStrawData)
exportClasses(ModalityWeights)
exportClasses(Neighbor)
exportClasses(Seurat)
exportClasses(SeuratCommand)
exportClasses(SpatialImage)
exportClasses(TransferAnchorSet)
exportClasses(VisiumV1)
exportClasses(VisiumV2)
importClassesFrom(Matrix,dgCMatrix)
importClassesFrom(SeuratObject,Assay)
importClassesFrom(SeuratObject,DimReduc)
importClassesFrom(SeuratObject,FOV)
importClassesFrom(SeuratObject,Graph)
importClassesFrom(SeuratObject,JackStrawData)
importClassesFrom(SeuratObject,Neighbor)
importClassesFrom(SeuratObject,Seurat)
importClassesFrom(SeuratObject,SeuratCommand)
importClassesFrom(SeuratObject,SpatialImage)
importFrom(KernSmooth,bkde)
importFrom(MASS,ginv)
importFrom(MASS,glm.nb)
importFrom(MASS,lda)
importFrom(Matrix,Matrix)
importFrom(Matrix,as.matrix)
importFrom(Matrix,colMeans)
importFrom(Matrix,colSums)
importFrom(Matrix,crossprod)
importFrom(Matrix,diag)
importFrom(Matrix,qrR)
importFrom(Matrix,readMM)
importFrom(Matrix,rowMeans)
importFrom(Matrix,rowSums)
importFrom(Matrix,sparse.model.matrix)
importFrom(Matrix,sparseMatrix)
importFrom(Matrix,summary)
importFrom(Matrix,t)
importFrom(RANN,nn2)
importFrom(RColorBrewer,brewer.pal)
importFrom(RColorBrewer,brewer.pal.info)
importFrom(ROCR,performance)
importFrom(ROCR,prediction)
importFrom(RSpectra,eigs_sym)
importFrom(Rcpp,evalCpp)
importFrom(RcppAnnoy,AnnoyAngular)
importFrom(RcppAnnoy,AnnoyEuclidean)
importFrom(RcppAnnoy,AnnoyHamming)
importFrom(RcppAnnoy,AnnoyManhattan)
importFrom(RcppHNSW,hnsw_build)
importFrom(RcppHNSW,hnsw_search)
importFrom(Rtsne,Rtsne)
importFrom(SeuratObject,"%!NA%")
importFrom(SeuratObject,"%NA%")
importFrom(SeuratObject,"%iff%")
importFrom(SeuratObject,"%||%")
importFrom(SeuratObject,"DefaultAssay<-")
importFrom(SeuratObject,"DefaultBoundary<-")
importFrom(SeuratObject,"DefaultLayer<-")
importFrom(SeuratObject,"Idents<-")
importFrom(SeuratObject,"Index<-")
importFrom(SeuratObject,"JS<-")
importFrom(SeuratObject,"Key<-")
importFrom(SeuratObject,"LayerData<-")
importFrom(SeuratObject,"Loadings<-")
importFrom(SeuratObject,"Misc<-")
importFrom(SeuratObject,"Project<-")
importFrom(SeuratObject,"Tool<-")
importFrom(SeuratObject,"VariableFeatures<-")
importFrom(SeuratObject,.CalcN)
importFrom(SeuratObject,.CheckFmargin)
importFrom(SeuratObject,.FilterObjects)
importFrom(SeuratObject,.MARGIN)
importFrom(SeuratObject,.PropagateList)
importFrom(SeuratObject,.SparseSlots)
importFrom(SeuratObject,AddMetaData)
importFrom(SeuratObject,Assays)
importFrom(SeuratObject,AttachDeps)
importFrom(SeuratObject,Boundaries)
importFrom(SeuratObject,CastAssay)
importFrom(SeuratObject,Cells)
importFrom(SeuratObject,CellsByIdentities)
importFrom(SeuratObject,Command)
importFrom(SeuratObject,CreateAssayObject)
importFrom(SeuratObject,CreateCentroids)
importFrom(SeuratObject,CreateDimReducObject)
importFrom(SeuratObject,CreateFOV)
importFrom(SeuratObject,CreateMolecules)
importFrom(SeuratObject,CreateSegmentation)
importFrom(SeuratObject,CreateSeuratObject)
importFrom(SeuratObject,DefaultAssay)
importFrom(SeuratObject,DefaultBoundary)
importFrom(SeuratObject,DefaultDimReduc)
importFrom(SeuratObject,DefaultFOV)
importFrom(SeuratObject,DefaultLayer)
importFrom(SeuratObject,Distances)
importFrom(SeuratObject,Embeddings)
importFrom(SeuratObject,EmptyDF)
importFrom(SeuratObject,Features)
importFrom(SeuratObject,FetchData)
importFrom(SeuratObject,GetAssayData)
importFrom(SeuratObject,GetImage)
importFrom(SeuratObject,GetTissueCoordinates)
importFrom(SeuratObject,HVFInfo)
importFrom(SeuratObject,Idents)
importFrom(SeuratObject,Images)
importFrom(SeuratObject,Index)
importFrom(SeuratObject,Indices)
importFrom(SeuratObject,IsGlobal)
importFrom(SeuratObject,IsSparse)
importFrom(SeuratObject,JS)
importFrom(SeuratObject,JoinLayers)
importFrom(SeuratObject,Key)
importFrom(SeuratObject,Keys)
importFrom(SeuratObject,LayerData)
importFrom(SeuratObject,Layers)
importFrom(SeuratObject,Loadings)
importFrom(SeuratObject,LogSeuratCommand)
importFrom(SeuratObject,Misc)
importFrom(SeuratObject,Molecules)
importFrom(SeuratObject,Neighbors)
importFrom(SeuratObject,Overlay)
importFrom(SeuratObject,Project)
importFrom(SeuratObject,Radius)
importFrom(SeuratObject,Reductions)
importFrom(SeuratObject,RenameAssays)
importFrom(SeuratObject,RenameCells)
importFrom(SeuratObject,RenameIdents)
importFrom(SeuratObject,ReorderIdent)
importFrom(SeuratObject,RowMergeSparseMatrices)
importFrom(SeuratObject,SVFInfo)
importFrom(SeuratObject,SetAssayData)
importFrom(SeuratObject,SetIdent)
importFrom(SeuratObject,SparseEmptyMatrix)
importFrom(SeuratObject,SpatiallyVariableFeatures)
importFrom(SeuratObject,StashIdent)
importFrom(SeuratObject,Stdev)
importFrom(SeuratObject,StitchMatrix)
importFrom(SeuratObject,Tool)
importFrom(SeuratObject,UpdateSeuratObject)
importFrom(SeuratObject,UpdateSlots)
importFrom(SeuratObject,VariableFeatures)
importFrom(SeuratObject,WhichCells)
importFrom(SeuratObject,as.Graph)
importFrom(SeuratObject,as.Neighbor)
importFrom(SeuratObject,as.Seurat)
importFrom(SeuratObject,as.sparse)
importFrom(cluster,clara)
importFrom(cowplot,get_legend)
importFrom(cowplot,plot_grid)
importFrom(cowplot,theme_cowplot)
importFrom(fastDummies,dummy_cols)
importFrom(fitdistrplus,fitdist)
importFrom(future,nbrOfWorkers)
importFrom(future,plan)
importFrom(future.apply,future_lapply)
importFrom(future.apply,future_sapply)
importFrom(generics,components)
importFrom(ggplot2,Geom)
importFrom(ggplot2,GeomPolygon)
importFrom(ggplot2,GeomViolin)
importFrom(ggplot2,aes)
importFrom(ggplot2,after_scale)
importFrom(ggplot2,alpha)
importFrom(ggplot2,annotation_custom)
importFrom(ggplot2,annotation_raster)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,coord_fixed)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,cut_number)
importFrom(ggplot2,discrete_scale)
importFrom(ggplot2,draw_key_point)
importFrom(ggplot2,dup_axis)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,fortify)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_blank)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_density)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_jitter)
importFrom(ggplot2,geom_label)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_polygon)
importFrom(ggplot2,geom_raster)
importFrom(ggplot2,geom_rect)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_violin)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggplot_build)
importFrom(ggplot2,ggproto)
importFrom(ggplot2,ggproto_parent)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guide_colorbar)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,layer)
importFrom(ggplot2,layer_scales)
importFrom(ggplot2,margin)
importFrom(ggplot2,position_dodge)
importFrom(ggplot2,position_jitterdodge)
importFrom(ggplot2,scale_alpha)
importFrom(ggplot2,scale_alpha_manual)
importFrom(ggplot2,scale_alpha_ordinal)
importFrom(ggplot2,scale_color_brewer)
importFrom(ggplot2,scale_color_distiller)
importFrom(ggplot2,scale_color_gradient)
importFrom(ggplot2,scale_color_gradientn)
importFrom(ggplot2,scale_color_identity)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_brewer)
importFrom(ggplot2,scale_fill_continuous)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_fill_viridis_c)
importFrom(ggplot2,scale_radius)
importFrom(ggplot2,scale_size)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_x_log10)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,scale_y_discrete)
importFrom(ggplot2,scale_y_log10)
importFrom(ggplot2,scale_y_reverse)
importFrom(ggplot2,stat_density2d)
importFrom(ggplot2,stat_qq)
importFrom(ggplot2,sym)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,theme_void)
importFrom(ggplot2,transform_position)
importFrom(ggplot2,unit)
importFrom(ggplot2,vars)
importFrom(ggplot2,waiver)
importFrom(ggplot2,xlab)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylab)
importFrom(ggplot2,ylim)
importFrom(ggrepel,geom_label_repel)
importFrom(ggrepel,geom_text_repel)
importFrom(ggridges,geom_density_ridges)
importFrom(ggridges,theme_ridges)
importFrom(grDevices,as.raster)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,png)
importFrom(grDevices,rgb)
importFrom(graphics,axis)
importFrom(graphics,image)
importFrom(graphics,locator)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,plot.new)
importFrom(graphics,smoothScatter)
importFrom(graphics,title)
importFrom(grid,addGrob)
importFrom(grid,editGrob)
importFrom(grid,gTree)
importFrom(grid,gpar)
importFrom(grid,grobName)
importFrom(grid,grobTree)
importFrom(grid,nullGrob)
importFrom(grid,pointsGrob)
importFrom(grid,rasterGrob)
importFrom(grid,unit)
importFrom(grid,viewport)
importFrom(httr,GET)
importFrom(httr,accept_json)
importFrom(httr,build_url)
importFrom(httr,content)
importFrom(httr,parse_url)
importFrom(httr,status_code)
importFrom(httr,timeout)
importFrom(ica,icafast)
importFrom(ica,icaimax)
importFrom(ica,icajade)
importFrom(igraph,E)
importFrom(igraph,cluster_leiden)
importFrom(igraph,graph.adjacency)
importFrom(igraph,graph_from_adj_list)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(igraph,membership)
importFrom(igraph,plot.igraph)
importFrom(irlba,irlba)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,read_json)
importFrom(lifecycle,deprecate_soft)
importFrom(lifecycle,deprecate_stop)
importFrom(lifecycle,deprecate_warn)
importFrom(lifecycle,deprecated)
importFrom(lifecycle,is_present)
importFrom(lmtest,lrtest)
importFrom(matrixStats,rowAnyNAs)
importFrom(matrixStats,rowMeans2)
importFrom(matrixStats,rowSds)
importFrom(matrixStats,rowSums2)
importFrom(methods,"slot<-")
importFrom(methods,.hasSlot)
importFrom(methods,as)
importFrom(methods,getMethod)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,setAs)
importFrom(methods,setClass)
importFrom(methods,setClassUnion)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(methods,setOldClass)
importFrom(methods,setValidity)
importFrom(methods,signature)
importFrom(methods,slot)
importFrom(methods,slotNames)
importFrom(miniUI,gadgetTitleBar)
importFrom(miniUI,miniButtonBlock)
importFrom(miniUI,miniContentPanel)
importFrom(miniUI,miniPage)
importFrom(miniUI,miniTitleBarButton)
importFrom(patchwork,plot_layout)
importFrom(patchwork,wrap_plots)
importFrom(pbapply,pbapply)
importFrom(pbapply,pblapply)
importFrom(pbapply,pbsapply)
importFrom(plotly,add_annotations)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(plotly,raster2uri)
importFrom(png,readPNG)
importFrom(progressr,progressor)
importFrom(reticulate,import)
importFrom(reticulate,py_module_available)
importFrom(reticulate,py_set_seed)
importFrom(rlang,"!!!")
importFrom(rlang,"!!")
importFrom(rlang,.data)
importFrom(rlang,abort)
importFrom(rlang,arg_match)
importFrom(rlang,arg_match0)
importFrom(rlang,as_label)
importFrom(rlang,as_name)
importFrom(rlang,caller_env)
importFrom(rlang,check_installed)
importFrom(rlang,data_sym)
importFrom(rlang,data_syms)
importFrom(rlang,enquo)
importFrom(rlang,exec)
importFrom(rlang,inform)
importFrom(rlang,is_integerish)
importFrom(rlang,is_na)
importFrom(rlang,is_quosure)
importFrom(rlang,is_scalar_character)
importFrom(rlang,is_scalar_integerish)
importFrom(rlang,quo_get_env)
importFrom(rlang,quo_get_expr)
importFrom(rlang,sym)
importFrom(rlang,warn)
importFrom(scales,brewer_pal)
importFrom(scales,hue_pal)
importFrom(scales,rescale)
importFrom(scales,squish_infinite)
importFrom(scales,zero_range)
importFrom(scattermore,geom_scattermore)
importFrom(sctransform,correct_counts)
importFrom(sctransform,get_residual_var)
importFrom(sctransform,get_residuals)
importFrom(sctransform,vst)
importFrom(shiny,brushOpts)
importFrom(shiny,brushedPoints)
importFrom(shiny,clickOpts)
importFrom(shiny,fillRow)
importFrom(shiny,hoverOpts)
importFrom(shiny,nearPoints)
importFrom(shiny,observe)
importFrom(shiny,observeEvent)
importFrom(shiny,plotOutput)
importFrom(shiny,reactiveVal)
importFrom(shiny,reactiveValues)
importFrom(shiny,renderPlot)
importFrom(shiny,renderPrint)
importFrom(shiny,renderUI)
importFrom(shiny,runGadget)
importFrom(shiny,selectInput)
importFrom(shiny,sidebarPanel)
importFrom(shiny,sliderInput)
importFrom(shiny,stopApp)
importFrom(shiny,tags)
importFrom(shiny,uiOutput)
importFrom(shiny,updateSelectInput)
importFrom(shiny,verbatimTextOutput)
importFrom(spatstat.explore,markvario)
importFrom(spatstat.geom,ppp)
importFrom(stats,aggregate)
importFrom(stats,anova)
importFrom(stats,approxfun)
importFrom(stats,as.dist)
importFrom(stats,as.formula)
importFrom(stats,ave)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,dist)
importFrom(stats,dnorm)
importFrom(stats,glm)
importFrom(stats,hclust)
importFrom(stats,kmeans)
importFrom(stats,lm)
importFrom(stats,loess)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(stats,pnbinom)
importFrom(stats,poisson)
importFrom(stats,prcomp)
importFrom(stats,predict)
importFrom(stats,prop.test)
importFrom(stats,quantile)
importFrom(stats,qunif)
importFrom(stats,relevel)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,t.test)
importFrom(stats,var)
importFrom(stats,wilcox.test)
importFrom(tibble,tibble)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(utils,argsAnywhere)
importFrom(utils,capture.output)
importFrom(utils,file_test)
importFrom(utils,globalVariables)
importFrom(utils,head)
importFrom(utils,isS3method)
importFrom(utils,isS3stdGeneric)
importFrom(utils,lsf.str)
importFrom(utils,methods)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
importFrom(utils,read.delim)
importFrom(utils,read.table)
importFrom(utils,setTxtProgressBar)
importFrom(utils,tail)
importFrom(utils,txtProgressBar)
importFrom(utils,write.table)
importFrom(uwot,umap)
importFrom(uwot,umap2)
importFrom(uwot,umap_transform)
importMethodsFrom(Matrix,t)
useDynLib(Seurat)
