[![CRAN Version](https://www.r-pkg.org/badges/version/Seurat)](https://cran.r-project.org/package=Seurat)
[![CRAN Downloads](https://cranlogs.r-pkg.org/badges/Seurat)](https://cran.r-project.org/package=Seurat)


# Seurat v5

Seurat is an R toolkit for single-cell genomics, developed and maintained by the [Satija Lab](https://satijalab.org/) at [NYGC](https://www.nygenome.org/).

> We are excited to release Seurat v5! This update introduces new functionality for spatial, multimodal, and scalable single-cell analysis.
>
> Seurat v5 is backwards-compatible with previous versions, so that users will continue to be able to re-run existing workflows. 

Installation instructions, documentation, and tutorials can be found at:

* https://satijalab.org/seurat

Seurat can be successfully installed in R on any system (Mac OS X, Linux, Windows).

Improvements and new features are added on a regular basis. For the most up-to-date development version, refer to the `main` branch. For the most recent version released on CRAN, refer to the `cran` branch.

Please post under [Issues](https://github.com/satijalab/seurat/issues) with any bug reports, feature requests, etc., and use [Discussions](https://github.com/satijalab/seurat/discussions) to engage with the wider Seurat community on analysis questions and other topics. [PRs](https://github.com/satijalab/seurat/pulls) are welcome if you would like to contribute.

For a version history/changelog, please see the [NEWS file](https://github.com/satijalab/seurat/blob/main/NEWS.md).
