% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualization.R
\name{ISpatialDimPlot}
\alias{ISpatialDimPlot}
\title{Visualize clusters spatially and interactively}
\usage{
ISpatialDimPlot(
  object,
  image = NULL,
  image.scale = "lowres",
  group.by = NULL,
  alpha = c(0.3, 1)
)
}
\arguments{
\item{object}{A Seurat object}

\item{image}{Name of the image to use in the plot}

\item{image.scale}{Choose the scale factor ("lowres"/"hires") to apply in
order to matchthe plot with the specified `image` - defaults to "lowres"}

\item{group.by}{Name of meta.data column to group the data by}

\item{alpha}{Controls opacity of spots. Provide as a vector specifying the
min and max for SpatialFeaturePlot. For SpatialDimPlot, provide a single
alpha value for each plot.}
}
\value{
Returns final plot as a ggplot object
}
\description{
Visualize clusters spatially and interactively
}
\concept{spatial}
\concept{visualization}
