% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R, R/objects.R
\name{ScaleFactors}
\alias{ScaleFactors}
\alias{scalefactors}
\alias{ScaleFactors.SlideSeq}
\alias{ScaleFactors.STARmap}
\alias{ScaleFactors.VisiumV1}
\alias{ScaleFactors.VisiumV2}
\title{Get image scale factors}
\usage{
ScaleFactors(object, ...)

scalefactors(spot = 1, fiducial = 1, hires = 1, lowres = 1)

\method{ScaleFactors}{SlideSeq}(object, ...)

\method{ScaleFactors}{STARmap}(object, ...)

\method{ScaleFactors}{VisiumV1}(object, ...)

\method{ScaleFactors}{VisiumV2}(object, ...)
}
\arguments{
\item{object}{An object to get scale factors from}

\item{...}{Arguments passed to other methods}

\item{spot}{Spot full resolution scale factor}

\item{fiducial}{Fiducial full resolution scale factor}

\item{hires}{High resolutoin scale factor}

\item{lowres}{Low resolution scale factor}
}
\value{
An object of class \code{scalefactors}
}
\description{
Get image scale factors
}
\note{
\code{scalefactors} objects can be created with \code{scalefactors()}
}
\concept{objects}
\concept{spatial}
