% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reexports.R
\docType{import}
\name{components}
\alias{components}
\alias{\%||\%}
\alias{\%iff\%}
\alias{reexports}
\alias{AddMetaData}
\alias{as.Graph}
\alias{as.Neighbor}
\alias{as.Seurat}
\alias{as.sparse}
\alias{Assays}
\alias{Cells}
\alias{CellsByIdentities}
\alias{Command}
\alias{CreateAssayObject}
\alias{CreateDimReducObject}
\alias{CreateSeuratObject}
\alias{DefaultAssay}
\alias{DefaultAssay<-}
\alias{Distances}
\alias{Embeddings}
\alias{FetchData}
\alias{GetAssayData}
\alias{GetImage}
\alias{GetTissueCoordinates}
\alias{HVFInfo}
\alias{Idents}
\alias{Idents<-}
\alias{Images}
\alias{Index}
\alias{Index<-}
\alias{Indices}
\alias{IsGlobal}
\alias{JS}
\alias{JS<-}
\alias{Key}
\alias{Key<-}
\alias{Loadings}
\alias{Loadings<-}
\alias{LogSeuratCommand}
\alias{Misc}
\alias{Misc<-}
\alias{Neighbors}
\alias{Project}
\alias{Project<-}
\alias{Radius}
\alias{Reductions}
\alias{RenameCells}
\alias{RenameIdents}
\alias{ReorderIdent}
\alias{RowMergeSparseMatrices}
\alias{SetAssayData}
\alias{SetIdent}
\alias{SpatiallyVariableFeatures}
\alias{StashIdent}
\alias{Stdev}
\alias{SVFInfo}
\alias{Tool}
\alias{Tool<-}
\alias{UpdateSeuratObject}
\alias{VariableFeatures}
\alias{VariableFeatures<-}
\alias{WhichCells}
\title{Objects exported from other packages}
\usage{
components(object, ...)

x \%||\% y

x \%iff\% y
}
\keyword{internal}
\description{
These objects are imported from other packages. Follow the links
below to see their documentation.

\describe{
  \item{SeuratObject}{\code{\link[SeuratObject]{AddMetaData}}, \code{\link[SeuratObject]{as.Graph}}, \code{\link[SeuratObject]{as.Neighbor}}, \code{\link[SeuratObject]{as.Seurat}}, \code{\link[SeuratObject]{as.sparse}}, \code{\link[SeuratObject:ObjectAccess]{Assays}}, \code{\link[SeuratObject]{Cells}}, \code{\link[SeuratObject]{CellsByIdentities}}, \code{\link[SeuratObject]{Command}}, \code{\link[SeuratObject]{CreateAssayObject}}, \code{\link[SeuratObject]{CreateDimReducObject}}, \code{\link[SeuratObject]{CreateSeuratObject}}, \code{\link[SeuratObject]{DefaultAssay}}, \code{\link[SeuratObject:DefaultAssay]{DefaultAssay<-}}, \code{\link[SeuratObject]{Distances}}, \code{\link[SeuratObject]{Embeddings}}, \code{\link[SeuratObject]{FetchData}}, \code{\link[SeuratObject:AssayData]{GetAssayData}}, \code{\link[SeuratObject]{GetImage}}, \code{\link[SeuratObject]{GetTissueCoordinates}}, \code{\link[SeuratObject:VariableFeatures]{HVFInfo}}, \code{\link[SeuratObject]{Idents}}, \code{\link[SeuratObject:Idents]{Idents<-}}, \code{\link[SeuratObject]{Images}}, \code{\link[SeuratObject:NNIndex]{Index}}, \code{\link[SeuratObject:NNIndex]{Index<-}}, \code{\link[SeuratObject]{Indices}}, \code{\link[SeuratObject]{IsGlobal}}, \code{\link[SeuratObject]{JS}}, \code{\link[SeuratObject:JS]{JS<-}}, \code{\link[SeuratObject]{Key}}, \code{\link[SeuratObject:Key]{Key<-}}, \code{\link[SeuratObject]{Loadings}}, \code{\link[SeuratObject:Loadings]{Loadings<-}}, \code{\link[SeuratObject]{LogSeuratCommand}}, \code{\link[SeuratObject]{Misc}}, \code{\link[SeuratObject:Misc]{Misc<-}}, \code{\link[SeuratObject:ObjectAccess]{Neighbors}}, \code{\link[SeuratObject]{Project}}, \code{\link[SeuratObject:Project]{Project<-}}, \code{\link[SeuratObject]{Radius}}, \code{\link[SeuratObject:ObjectAccess]{Reductions}}, \code{\link[SeuratObject]{RenameCells}}, \code{\link[SeuratObject:Idents]{RenameIdents}}, \code{\link[SeuratObject:Idents]{ReorderIdent}}, \code{\link[SeuratObject]{RowMergeSparseMatrices}}, \code{\link[SeuratObject:AssayData]{SetAssayData}}, \code{\link[SeuratObject:Idents]{SetIdent}}, \code{\link[SeuratObject:VariableFeatures]{SpatiallyVariableFeatures}}, \code{\link[SeuratObject:Idents]{StashIdent}}, \code{\link[SeuratObject]{Stdev}}, \code{\link[SeuratObject:VariableFeatures]{SVFInfo}}, \code{\link[SeuratObject]{Tool}}, \code{\link[SeuratObject:Tool]{Tool<-}}, \code{\link[SeuratObject]{UpdateSeuratObject}}, \code{\link[SeuratObject]{VariableFeatures}}, \code{\link[SeuratObject:VariableFeatures]{VariableFeatures<-}}, \code{\link[SeuratObject]{WhichCells}}}
}}

